import type { BuiltinOAuthProviderNames } from "@gel/auth-core";
import { WebAuthnClient } from "@gel/auth-core/webauthn";
export interface AuthOptions {
    baseUrl: string;
    authRoutesPath?: string;
    authCookieName?: string;
    pkceVerifierCookieName?: string;
    passwordResetPath?: string;
    magicLinkFailurePath?: string;
}
type OptionalOptions = "passwordResetPath" | "magicLinkFailurePath";
export type AuthConfig = Required<Omit<AuthOptions, OptionalOptions>> & Pick<AuthOptions, OptionalOptions> & {
    authRoute: string;
};
export declare function getConfig(options: AuthOptions): {
    baseUrl: string;
    authRoutesPath: string;
    authCookieName: string;
    pkceVerifierCookieName: string;
    passwordResetPath: string | undefined;
    magicLinkFailurePath: string | undefined;
    authRoute: string;
};
export default function createClientAuth(options: AuthOptions): ClientAuth;
export declare class ClientAuth {
    protected readonly config: AuthConfig;
    protected readonly isSecure: boolean;
    readonly webAuthnClient: WebAuthnClient;
    getOAuthUrl(providerName: BuiltinOAuthProviderNames): string;
    getBuiltinUIUrl(): string;
    getBuiltinUISignUpUrl(): string;
    getSignoutUrl(): string;
}
export {};
